/*
 * This file is part of dial.
 *
 * dial is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 * 
 * dial is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with dial; see the file COPYING.  If not, write to the Free
 * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   Copyright 1994 Dominic Giampaolo
 *   Copyright 1996 Torsten Martinsen
 *
 * $Id: dial.h,v 1.19 1996/03/27 18:31:31 torsten Exp $
 */

#include "libsx.h"

/*
 * MODULES should be 1 if you have compiled kernel PPP support as a module.
 * 'dial' will then load the modules 'slhc' and 'ppp'.
 * Set BSD_COMP to 1 if you want to use compressed headers.
 * 'dial' will then load the module 'bsd_comp'.
 */
#define MODULES		1
#define BSD_COMP	1

/*
 * If you want dial to show detailed information while connecting, set
 * SHOW_CONNECT_STATUS to 1. For this to work optimally, make sure your chat
 * script includes the sequence
 *
 *	ABORT BUSY ABORT 'NO CARRIER' ABORT 'NO DIALTONE'
 *
 * as shown in 'sample-scripts/ppp-connect'.
 * If set SHOW_CONNECT_STATUS to 0, you need to install the 'ip-up' and
 * 'ip-down' scripts in /etc/ppp - otherwise dial can not tell whether the
 * link is up.
 */
#define SHOW_CONNECT_STATUS	1


/*
 * These should conform to the Linux FSSTND.
 */
#define PPPD		"/usr/sbin/pppd"	/* Path to PPP daemon */
#define PPPDFILE	"/etc/ppp/linkinfo"	/* Created by /etc/ppp/ip-up */
#define PPPDPIDFILE	"/var/run/ppp0.pid"	/* PID of PPP daemon */
#define CONNECTSCRIPT	"/etc/ppp/dial-ppp-connect"
#define SYSLOGFILE	"/var/adm/messages"	/* Syslog messages */
#define INSMOD		"/sbin/insmod"		/* Path to insmod */
#define RMMOD		"/sbin/rmmod"		/* Path to rmmod */

/*
 * It should not be necessary to change any of the following defines.
 */
#define WIDTH 130
#define HEIGHT 180

#define TITLEFONT	"-b&h-lucidatypewriter-medium-r-*-*-*-180-75-75-*-*-*-*"
#define BUTTONFONT	"-adobe-helvetica-bold-r-*-*-*-140-75-75-*-*-*-*"

#define GREY		"grey"	/* Colour for greyed-out text */

#define TICKINTERVAL 1000	/* How often to update clock (ms) */
#define COSTINTERVAL 5		/* How often to update cost (seconds) */

#define SYSRCFILE	"/etc/dialrc"
#define USERRCFILE	"~/.dialrc"
#define DEFAULTLOGFILE  "~/.dialcosts"

/* Don't change this yet. */
#define SELECTNUMBER		0

typedef void (*Voidfunc)(void);

/*
 * Globals
 */
extern int testing;
extern int greycol;
extern Widget button;
extern char * number;

/*
 * States for set_display_state()
 */
#define DS_NOT_CONNECTED	0
#define DS_CONNECTING		1
#define DS_CONNECT_TIMED_OUT	2
#define DS_CONNECTED		3
#define DS_CONNECT_FAILED	4
#define DS_BUSY			5
#define DS_WAITING		6
#define DS_SER_CONN_EST		7
#define DS_BANNER		8
#define DS_COPYRIGHT		9

/*
 * Connection states
 */
#define CSTATE_NC	  0
#define CSTATE_CONNECTED  1
#define CSTATE_TRYING	  2
#define CSTATE_BUSY	  3

typedef struct
{
  int redialinterval;
  int connecttimeout;
  int redial;
  float dialcost;
  char * logfile;
  char * defaultnumber;
} GlobalOptions;

extern GlobalOptions global;

/*
 * Prototypes
 */

/* callbacks.c */
void connectcb(Widget w, void *junk);
void quitcb(Widget w, void *junk);
void selectcb(Widget w, void * junk);
void hangup_done(void);

/* connect.c */
void doconnect(int * connectedp);
void hangup(Voidfunc func);

/* cost.c */
void clocktick(void * junk);
void startclock(void);
void stopclock(void);
void log_costs(void);
void add_dial_cost(void);

/* display.c */
void update_display(int doclock, int docost, int dorate);
void set_display(char *clockstr, char *coststr, char *ratestr);
void repaint(Widget w, int new_width, int new_height, void *data);
void repaint1(Widget w, int new_width, int new_height, void *data);
void set_display_state(int state);
void removebanner(void * junk);

/* modules.c */
void load_module(char * name);
void unload_module(char * name);

/* readrc.c */
void parserc(char * rcfile);
