/*
 * This file is part of dial.
 *
 * dial is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 * 
 * dial is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with dial; see the file COPYING.  If not, write to the Free
 * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   Copyright 1994 Dominic Giampaolo
 *   Copyright 1996 Torsten Martinsen
 *
 * $Id: display.c,v 1.12 1996/03/27 09:54:24 torsten Exp $
 */

#include <stdio.h>
#include <time.h>

#include "dial.h"


static int dw, dh, dw1, dh1;
static int display_state = DS_BANNER;

static char * clockstring = NULL, * coststring = NULL, * ratestring = NULL;
static int textspacing, starty;
static XFont font, font1;
static Widget da, da1;

static void DrawCenteredText(char *str, XFont font, int width, int y);
static void do_repaint(Widget w);
static void do_repaint1(Widget w);


void
set_display(char * clockstr, char * coststr, char * ratestr)
{
  clockstring = clockstr;
  coststring = coststr;
  ratestring = ratestr;
}

void
update_display(int doclock, int docost, int dorate)
{
  int y;
  char str[20];


  SetDrawArea(da);
  if (display_state != DS_CONNECTED)
    SetColor(greycol);
  
  y = starty+textspacing;

  if (doclock && clockstring)
    DrawCenteredText(clockstring, font, dw, y);
  y += 2*textspacing;
  if (docost && coststring)
    DrawCenteredText(coststring, font, dw, y);
  if (dorate && ratestring)
    {
      y += 2*textspacing;
      strcpy(str, ratestring);
      strcat(str, "/min");
      DrawCenteredText(str, font, dw, y);
    }
  if (display_state != DS_CONNECTED)
    SetColor(BLACK);
}

static void
DrawCenteredText(char * str, XFont font, int width, int y)
{
  DrawText(str, (width-TextWidth(font, str))/2, y);
}

void
repaint(Widget w, int new_width, int new_height, void *data)
{
  int fontheight;
  
  dw = new_width;
  dh = new_height;
  da = w;
  
  font = GetWidgetFont(w);
  fontheight = FontHeight(font);
  textspacing = 8*fontheight/6;
  starty = (dh-6*textspacing)/2 + fontheight;

  do_repaint(w);
}

void
repaint1(Widget w, int new_width, int new_height, void *data)
{
  dw1 = new_width;
  dh1 = new_height;
  da1 = w;
  
  font1 = GetWidgetFont(w);

  do_repaint1(w);
}

static void
do_repaint1(Widget w)
{
  char * p, buf[40];
  
  static char * msgs[] = {
    "Not connected",	/* DS_NOT_CONNECTED */
    "Dialing %s..",	/* DS_CONNECTING */
    "Timed out!",	/* DS_CONNECT_TIMED_OUT */
    "Connected",	/* DS_CONNECTED */
    "Connect failed!",	/* DS_CONNECT_FAILED */
    "Line was busy!",	/* DS_BUSY */
    "Wait for redial",	/* DS_WAITING */
    "Getting IP..",	/* DS_SER_CONN_EST */
    "dial " VERSION,	/* DS_BANNER */
    "(C) T. Martinsen"	/* DS_COPYRIGHT */
  };
  
  SetDrawArea(w);
  ClearDrawArea();
  p = msgs[display_state];
  if (display_state == DS_CONNECTING)
    {
      sprintf(buf, p, number);
      p = buf;
    }
  DrawCenteredText(p, font1, dw1, (dh1+FontHeight(font1))/2-2);
}

static void
do_repaint(Widget w)
{
  int y;


  SetDrawArea(w);
  ClearDrawArea();

  y = starty;
  DrawCenteredText("Time", font, dw, y);
  y += 2*textspacing;
  DrawCenteredText("Cost", font, dw, y);
  y += 2*textspacing;
  DrawCenteredText("Rate", font, dw, y);
  update_display(1, 1, 1);
}

void
set_display_state(int state)
{
  display_state = state;
  do_repaint1(da1);
  update_display(1, 1, 1);
}

void
removebanner(void * junk)
{
  if (display_state == DS_BANNER)
    {
      display_state = DS_COPYRIGHT;
      AddTimeOut(3000, removebanner, NULL);
    }
  else if (display_state == DS_COPYRIGHT)
    display_state = DS_NOT_CONNECTED;
  do_repaint1(da1);
}
